#!/usr/bin/env python3
#******************************************************************************
# Copyright (C) 2017-2018 Thomas "Cakeisalie5" Touhey <thomas@touhey.fr>
# This file is part of the fingerd Python 3.x module, which is MIT-licensed.
#******************************************************************************
""" finger is both a protocol and a utility to get the information and
	status from a user on a distant machine. It was standardized in RFC 742
	in 1977, then in RFC 1288 in 1991, and has been abandoned by most
	people since.

	This Python module is a finger server implementation that allows you
	to give out real information as well as fictional information.
"""

from ._util import ConfigurationError, BindError, \
	FingerUser, FingerUserDelta, FingerFormatter, \
	FingerInterface, FingerLogger
from ._fiction import FingerFiction, FingerFictionInterface
from ._server import FingerServer

__all__ = ["version",
	"FingerUser", "FingerUserDelta", "FingerFormatter",
	"FingerInterface", "FingerLogger", "FingerServer", "FingerFiction",
	"FingerNativeInterface", "FingerFictionInterface",
	"ConfigurationError", "BindError"]

version = "0.1"

class _FingerNoNativeFoundInterface(FingerInterface):
	""" Placeholder that doesn't initiate. """

	def __init__(self, *args, **kwargs):
		raise NotImplementedError("Could not find a suitable " \
			"native interface.")

try:
	from ._posix import FingerPOSIXInterface as FingerNativeInterface
except ModuleNotFoundError:
	# TODO: win32 finger interface?

	FingerNativeInterface = _FingerNoNativeFoundInterface

# End of file.
